@@ -31,14 +31,15 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "version.h"
 #include "svggenerator.h"
 
-using namespace std;
 namespace highlight
 {
 
 SVGGenerator::SVGGenerator()
     : CodeGenerator ( SVG )
 {
-    spacer = " ";
+    //spacer = " ";
+    spacer = "&#160;";
+    maskWs=true;
     newLineTag = "\n";
     styleCommentOpen="/*";
     styleCommentClose="*/";
@@ -187,6 +188,9 @@ string SVGGenerator::getFooter()
 string SVGGenerator::maskCharacter ( unsigned  char c )
 {
     switch ( c ) {
+      case ' ' :
+        return spacer;
+        break;
     case '<' :
         return "&lt;";
         break;
