@@ -137,12 +137,12 @@ Revise su instalación.</translation>
         <translation type="unfinished">找不到语法定义文件.请检查安装.</translation>
     </message>
     <message>
-        <location line="+50"/>
+        <location line="+60"/>
         <source>Always at your service</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+14"/>
+        <location line="+16"/>
         <source>Select one or more files to open</source>
         <translation type="unfinished">选择一个或多个文件打开</translation>
     </message>
@@ -160,7 +160,7 @@ Revise su instalación.</translation>
         <translation type="obsolete">无法读取 &quot;%1&quot; 的Tag信息</translation>
     </message>
     <message>
-        <location line="+551"/>
+        <location line="+550"/>
         <location line="+31"/>
         <source>Output error</source>
         <translation type="unfinished">输出错误</translation>
@@ -176,7 +176,7 @@ Revise su instalación.</translation>
         <translation type="unfinished">你必须等译一个style输出文件！</translation>
     </message>
     <message>
-        <location line="+29"/>
+        <location line="+30"/>
         <source>Processing %1 (%2/%3)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -214,18 +214,18 @@ Lua Syntax error: %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+67"/>
+        <location line="+83"/>
         <source>Converted %1 files in %2 ms</source>
         <translation type="unfinished">文件%1 转换完毕，用时 %2 ms</translation>
     </message>
     <message>
-        <location line="+91"/>
+        <location line="+90"/>
         <source>Conversion of &quot;%1&quot; not possible.</source>
         <translation type="unfinished">No es posible la conversión de &quot;%1&quot;.</translation>
     </message>
     <message>
         <location line="+0"/>
-        <location line="+106"/>
+        <location line="+108"/>
         <location line="+22"/>
         <source>clipboard data</source>
         <translation type="unfinished">剪贴板数据</translation>
@@ -251,7 +251,7 @@ Lua Syntax error: %2</source>
         <translation type="unfinished">&quot;%1&quot;.的预览不可用.</translation>
     </message>
     <message>
-        <location line="+174"/>
+        <location line="+171"/>
         <source>Some plug-in effects may not be visible in the preview.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -320,18 +320,18 @@ Please send a note to as (at) andre-simon (dot) de if you have issues during tra
     </message>
     <message>
         <location line="+3"/>
-        <location line="+256"/>
+        <location line="+255"/>
         <source>Clear selection</source>
         <translation>移除选中项</translation>
     </message>
     <message>
-        <location line="-249"/>
+        <location line="-248"/>
         <source>Remove all input files.</source>
         <translation>清除所有输入文件.</translation>
     </message>
     <message>
         <location line="+3"/>
-        <location line="+256"/>
+        <location line="+255"/>
         <source>Clear all</source>
         <translation>移除所有</translation>
     </message>
@@ -340,27 +340,27 @@ Please send a note to as (at) andre-simon (dot) de if you have issues during tra
         <translation type="obsolete">Destino de salida</translation>
     </message>
     <message>
-        <location line="-217"/>
+        <location line="-216"/>
         <source>Output directory</source>
         <translation>输出目录</translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+25"/>
         <source>Select the output directory.</source>
         <translation>选择输出路径.</translation>
     </message>
     <message>
         <location line="+3"/>
-        <location line="+260"/>
-        <location line="+503"/>
-        <location line="+237"/>
-        <location line="+96"/>
-        <location line="+246"/>
+        <location line="+265"/>
+        <location line="+537"/>
+        <location line="+275"/>
+        <location line="+114"/>
+        <location line="+301"/>
         <source>...</source>
         <translation>...</translation>
     </message>
     <message>
-        <location line="-1333"/>
+        <location line="-1483"/>
         <source>Save output in the input file directories.</source>
         <translation>将输出保存在输入路径中.</translation>
     </message>
@@ -374,7 +374,7 @@ Please send a note to as (at) andre-simon (dot) de if you have issues during tra
         <translation type="obsolete">Opciones de salida</translation>
     </message>
     <message>
-        <location line="+293"/>
+        <location line="+291"/>
         <source>General</source>
         <translation>通用</translation>
     </message>
@@ -597,20 +597,20 @@ The result has to match the input file encoding.</source>
     </message>
     <message>
         <location line="+49"/>
-        <location line="+244"/>
-        <location line="+96"/>
-        <location line="+246"/>
+        <location line="+305"/>
+        <location line="+114"/>
+        <location line="+301"/>
         <source>Include the style information in each output file.</source>
         <translation>将样式表信息保存到每个输出文件中.</translation>
     </message>
     <message>
-        <location line="-583"/>
-        <location line="+586"/>
+        <location line="-717"/>
+        <location line="+720"/>
         <source>Embed style (CSS)</source>
         <translation>内嵌样式表 (CSS)</translation>
     </message>
     <message>
-        <location line="-573"/>
+        <location line="-707"/>
         <source>Add CSS information to each tag (do not use CSS class definitions).</source>
         <translation>CSS信息保存到每个Tag中(不使用CSS的类定义).</translation>
     </message>
@@ -624,15 +624,15 @@ The result has to match the input file encoding.</source>
         <translation type="obsolete">Archivo de estilo:</translation>
     </message>
     <message>
-        <location line="+27"/>
-        <location line="+316"/>
-        <location line="+246"/>
+        <location line="+33"/>
+        <location line="+395"/>
+        <location line="+301"/>
         <source>Name of the referenced style file.</source>
         <translation>外链样式表文件的名字.</translation>
     </message>
     <message>
-        <location line="-559"/>
-        <location line="+562"/>
+        <location line="-693"/>
+        <location line="+696"/>
         <source>highlight.css</source>
         <translation></translation>
     </message>
@@ -641,13 +641,13 @@ The result has to match the input file encoding.</source>
         <translation type="obsolete">Archivo de estilo a incluir:</translation>
     </message>
     <message>
-        <location line="-544"/>
-        <location line="+579"/>
+        <location line="-655"/>
+        <location line="+690"/>
         <source>Path of the CSS include file.</source>
         <translation>外链样式表的路径.</translation>
     </message>
     <message>
-        <location line="-572"/>
+        <location line="-671"/>
         <source>Select a CSS include file.</source>
         <translation>选择一个外链的样式表.</translation>
     </message>
@@ -657,7 +657,7 @@ The result has to match the input file encoding.</source>
         <translation>CSS类前缀:</translation>
     </message>
     <message>
-        <location line="+7"/>
+        <location line="+13"/>
         <source>Add a CSS class name prefix to avoid namespace clashes.</source>
         <translation>给CSS类添加前缀以避免由于命名空间引起的冲突..</translation>
     </message>
@@ -666,7 +666,7 @@ The result has to match the input file encoding.</source>
         <translation type="obsolete">Archivos de etiquetas e índice</translation>
     </message>
     <message>
-        <location line="+78"/>
+        <location line="+85"/>
         <source>Generate an index file with hyperlinks to all outputted files.</source>
         <translation>生成一个包含所有输出文件超链接的index文件.</translation>
     </message>
@@ -695,7 +695,7 @@ See ctags.sf.net for details.</source>
         <translation type="obsolete">选择一个ctags文件.</translation>
     </message>
     <message>
-        <location line="-52"/>
+        <location line="-59"/>
         <source>Misc</source>
         <translation>杂项</translation>
     </message>
@@ -729,7 +729,7 @@ See ctags.sf.net for details.</source>
         <translation type="obsolete">Lista ordenada</translation>
     </message>
     <message>
-        <location line="+20"/>
+        <location line="+27"/>
         <source>Add &amp;lt;pre&amp;gt; tags to the output, if the flag &quot;No document header and footer&quot; is selected.</source>
         <translation>当选中“忽略文档的header和footer”时，给输出添加&lt;pre&gt;标签.</translation>
     </message>
@@ -774,20 +774,20 @@ See ctags.sf.net for details.</source>
         <translation type="obsolete">Símbolos lindos</translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+20"/>
         <source>Embed style (defs)</source>
         <translatorcomment>Include style information in output</translatorcomment>
         <translation>内嵌页面样式 (defs)</translation>
     </message>
     <message>
-        <location line="+19"/>
+        <location line="+25"/>
         <source>Name of the referenced  style file.</source>
         <translatorcomment>Name of external style file</translatorcomment>
         <translation>被引用的样式表的文件名.</translation>
     </message>
     <message>
         <location line="+3"/>
-        <location line="+96"/>
+        <location line="+114"/>
         <source>highlight.sty</source>
         <translation></translation>
     </message>
@@ -796,27 +796,28 @@ See ctags.sf.net for details.</source>
         <translation type="obsolete">Incluir estilo:</translation>
     </message>
     <message>
-        <location line="-531"/>
+        <location line="-616"/>
         <source>Set encoding:</source>
         <translation>编码设置：</translation>
     </message>
     <message>
-        <location line="-557"/>
+        <location line="-561"/>
         <source>Output destination:</source>
         <translation>输出路径：</translation>
     </message>
     <message>
-        <location line="+756"/>
-        <location line="+223"/>
-        <location line="+96"/>
-        <location line="+246"/>
+        <location line="+760"/>
+        <location line="+284"/>
+        <location line="+114"/>
+        <location line="+301"/>
         <source>Stylesheet file:</source>
         <translation>外链样式表文件名：</translation>
     </message>
     <message>
-        <location line="-318"/>
-        <location line="+96"/>
-        <location line="+246"/>
+        <location line="-666"/>
+        <location line="+281"/>
+        <location line="+114"/>
+        <location line="+301"/>
         <source>Stylesheet include file:</source>
         <translation>包含的样式表文件：</translation>
     </message>
@@ -825,7 +826,7 @@ See ctags.sf.net for details.</source>
         <translation type="obsolete">读取ctags文件：</translation>
     </message>
     <message>
-        <location line="-1581"/>
+        <location line="-1725"/>
         <source>Highlight</source>
         <translation>Highlight</translation>
     </message>
@@ -835,32 +836,34 @@ See ctags.sf.net for details.</source>
         <translation>文件</translation>
     </message>
     <message>
-        <location line="+214"/>
+        <location line="+220"/>
         <source>Paste clipboard content into the preview window.</source>
         <translation>将剪贴板中的代码粘贴到预览窗口.</translation>
     </message>
     <message>
         <location line="+3"/>
-        <source>Paste from clipboard</source>
-        <translation>从剪贴板获取代码</translation>
+        <source>Paste from clipboard (%1)</source>
+        <oldsource>Paste from clipboard</oldsource>
+        <translation type="unfinished">从剪贴板获取代码</translation>
     </message>
     <message>
-        <location line="+42"/>
+        <location line="+35"/>
         <source>Copy highlighted code into the clipboard.</source>
         <translation>将高亮代码复制到剪贴板.</translation>
     </message>
     <message>
         <location line="+3"/>
-        <source>Copy preview to clipboard</source>
-        <translation>将预览结果复制到剪贴板</translation>
+        <source>Copy preview to clipboard (%1)</source>
+        <oldsource>Copy preview to clipboard</oldsource>
+        <translation type="unfinished">将预览结果复制到剪贴板</translation>
     </message>
     <message>
-        <location line="-32"/>
+        <location line="-25"/>
         <source>Select syntax:</source>
         <translation>代码语言：</translation>
     </message>
     <message>
-        <location line="-276"/>
+        <location line="-282"/>
         <source>Wi&amp;ndows</source>
         <oldsource>&amp;Windows</oldsource>
         <translation type="unfinished">窗口(&amp;W)</translation>
@@ -872,12 +875,12 @@ See ctags.sf.net for details.</source>
         <translation type="unfinished">代码高亮选项</translation>
     </message>
     <message>
-        <location line="+263"/>
+        <location line="+269"/>
         <source>Select the correct syntax of the code snippet.</source>
         <translation>给代码片段选择对应的语言格式.</translation>
     </message>
     <message>
-        <location line="+46"/>
+        <location line="+39"/>
         <source>Plug-ins</source>
         <translation>插件</translation>
     </message>
@@ -914,12 +917,12 @@ See ctags.sf.net for details.</source>
         <translation type="unfinished">传递给插件的一个可选路径</translation>
     </message>
     <message>
-        <location line="+7"/>
+        <location line="+19"/>
         <source>Select the plug-in input file.</source>
         <translation>选择传递给插件的文件.</translation>
     </message>
     <message>
-        <location line="+129"/>
+        <location line="+122"/>
         <source>BBCode</source>
         <translation>BBCode</translation>
     </message>
@@ -929,16 +932,15 @@ See ctags.sf.net for details.</source>
         <translation>样式表</translation>
     </message>
     <message>
-        <location line="+68"/>
         <source>Include:</source>
-        <translation>包含：</translation>
+        <translation type="vanished">包含：</translation>
     </message>
     <message>
         <source>Index/ctags</source>
         <translation type="obsolete">Index/ctags</translation>
     </message>
     <message>
-        <location line="+76"/>
+        <location line="+191"/>
         <source>Line numbering options:</source>
         <translation>行号选项：</translation>
     </message>
@@ -948,7 +950,7 @@ See ctags.sf.net for details.</source>
         <translation>根据列表顺序输出</translation>
     </message>
     <message>
-        <location line="+20"/>
+        <location line="+27"/>
         <source>Enclose in pre tags</source>
         <translation>包含在pre标记中</translation>
     </message>
@@ -964,16 +966,16 @@ See ctags.sf.net for details.</source>
         <translation>使用更友好的符号</translation>
     </message>
     <message>
-        <location line="+67"/>
-        <location line="+96"/>
+        <location line="+80"/>
+        <location line="+114"/>
         <source>Path of the style include file.</source>
         <translatorcomment>Ptah of file to be included in document style</translatorcomment>
         <translation>外链样式表的路径.</translation>
     </message>
     <message>
-        <location line="-89"/>
-        <location line="+96"/>
-        <location line="+246"/>
+        <location line="-95"/>
+        <location line="+114"/>
+        <location line="+301"/>
         <source>Select a style include file.</source>
         <translation>选择一个样式表文件.</translation>
     </message>
@@ -982,7 +984,7 @@ See ctags.sf.net for details.</source>
         <translation type="obsolete">Opciones de TeX</translation>
     </message>
     <message>
-        <location line="-310"/>
+        <location line="-383"/>
         <source>Embed style (macros)</source>
         <translation>内嵌页面样式 (macros)</translation>
     </message>
@@ -991,7 +993,7 @@ See ctags.sf.net for details.</source>
         <translation type="obsolete">Opciones de RTF</translation>
     </message>
     <message>
-        <location line="+93"/>
+        <location line="+111"/>
         <source>Add character stylesheets with formatting information.
 You can select the stylesheets in your word processor to reformat additional text.</source>
         <translatorcomment>For RTF output, Openoffice supports character stylesheets</translatorcomment>
@@ -1009,7 +1011,7 @@ You can select the stylesheets in your word processor to reformat additional tex
         <translation>页面大小：</translation>
     </message>
     <message>
-        <location line="+7"/>
+        <location line="+13"/>
         <source>Select a page size.</source>
         <translation>设置页面大小.</translation>
     </message>
@@ -1058,34 +1060,32 @@ You can select the stylesheets in your word processor to reformat additional tex
         <translation type="obsolete">Opciones de SVG</translation>
     </message>
     <message>
-        <location line="+27"/>
         <source>Image size:</source>
-        <translation>图像大小：</translation>
+        <translation type="vanished">图像大小：</translation>
     </message>
     <message>
-        <location line="+9"/>
         <source>Width:</source>
-        <translation>宽度：</translation>
+        <translation type="vanished">宽度：</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+57"/>
         <source>Enter the SVG width (may contain units).</source>
         <translatorcomment>Input SVG image width</translatorcomment>
         <translation>输入SVG图像宽度.</translation>
     </message>
     <message>
-        <location line="+7"/>
+        <location line="+20"/>
         <source>Height:</source>
         <translation>高度：</translation>
     </message>
     <message>
-        <location line="+10"/>
+        <location line="+16"/>
         <source>Enter the SVG height (may contain units).</source>
         <translatorcomment>Input SVG image height</translatorcomment>
         <translation>输入SVG图像高度.</translation>
     </message>
     <message>
-        <location line="+105"/>
+        <location line="+130"/>
         <source>No options defined.</source>
         <translation>没有可供选择的选项..</translation>
     </message>
@@ -1100,7 +1100,7 @@ You can select the stylesheets in your word processor to reformat additional tex
         <translation>高亮主题：</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+22"/>
         <source>Select a colour theme.</source>
         <translation>选择一个用于高亮的颜色主题.</translation>
     </message>
@@ -1117,7 +1117,7 @@ This feature is enabled tor C, C++, C# and Java code.</source>
         <translation>格式化代码:</translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+19"/>
         <source>Choose a formatting scheme.</source>
         <translation>选择一种代码格式化风格.</translation>
     </message>
@@ -1136,7 +1136,7 @@ This feature is enabled tor C, C++, C# and Java code.</source>
         <translation>关键字大小写：</translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+19"/>
         <source>Select a keyword case.</source>
         <translation>这是关键字大小写.</translation>
     </message>
@@ -1161,14 +1161,14 @@ This feature is enabled tor C, C++, C# and Java code.</source>
         <translation>制表符(Tab)宽度：</translation>
     </message>
     <message>
-        <location line="+10"/>
+        <location line="+16"/>
         <source>Enter the number of spaces which replace a tab.
 Set the width to 0 to keep tabs.</source>
         <translation>设置多少个空格替换一个制表符(Tab).
 设置为0时保留制表符(Tab).</translation>
     </message>
     <message>
-        <location line="+17"/>
+        <location line="+15"/>
         <source>Enable line wrapping.</source>
         <translation>启用自动换行.</translation>
     </message>
@@ -1178,12 +1178,12 @@ Set the width to 0 to keep tabs.</source>
         <translation>自动换行</translation>
     </message>
     <message>
-        <location line="+5"/>
+        <location line="+13"/>
         <source>Enter the maximum line length.</source>
         <translation>设定每行代码的最大长度.</translation>
     </message>
     <message>
-        <location line="+28"/>
+        <location line="+19"/>
         <source>Indent statements and function parameters after wrapping.</source>
         <translation>换行后自动缩进语句和函数参数.</translation>
     </message>
@@ -1193,7 +1193,7 @@ Set the width to 0 to keep tabs.</source>
         <translation>自动缩进</translation>
     </message>
     <message>
-        <location line="+26"/>
+        <location line="+21"/>
         <source>Font na&amp;me:</source>
         <oldsource>Font name:</oldsource>
         <translation type="unfinished">字体：</translation>
@@ -1203,12 +1203,12 @@ Set the width to 0 to keep tabs.</source>
         <translation type="obsolete">Seleccionar o introduzcir el nombre de la fuente.</translation>
     </message>
     <message>
-        <location line="+27"/>
+        <location line="+33"/>
         <source>Font size:</source>
         <translation>字体大小：</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+22"/>
         <source>Enter the font size.</source>
         <translation>输入字体大小.</translation>
     </message>
@@ -1224,12 +1224,12 @@ Set the width to 0 to keep tabs.</source>
         <translation>停靠浮动面板(&amp;D)</translation>
     </message>
     <message>
-        <location line="-1995"/>
+        <location line="-2179"/>
         <source>Preview</source>
         <translation>预览</translation>
     </message>
     <message>
-        <location line="+308"/>
+        <location line="+314"/>
         <source>Start the conversion of your input files.</source>
         <translation>点击按钮开始转换文件.</translation>
     </message>
@@ -1254,7 +1254,7 @@ Set the width to 0 to keep tabs.</source>
         <translation>将输出文件内容复制到剪贴板</translation>
     </message>
     <message>
-        <location line="+89"/>
+        <location line="+82"/>
         <source>Choose a plug-in script.</source>
         <translation>选择一个插件脚本.</translation>
     </message>
@@ -1275,7 +1275,7 @@ Set the width to 0 to keep tabs.</source>
         <translation>移除所有插件.</translation>
     </message>
     <message>
-        <location line="-424"/>
+        <location line="-423"/>
         <source>Output progress:</source>
         <translation>输出进度：</translation>
     </message>
@@ -1290,7 +1290,7 @@ Set the width to 0 to keep tabs.</source>
         <translation>帮助(&amp;H)</translation>
     </message>
     <message>
-        <location line="+1329"/>
+        <location line="+1430"/>
         <source>Set page color attribute to background color</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1300,7 +1300,12 @@ Set the width to 0 to keep tabs.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+451"/>
+        <location line="+93"/>
+        <source>I&amp;mage width:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+436"/>
         <source>Do not add line numbering to lines which were automatically wrapped.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1310,12 +1315,12 @@ Set the width to 0 to keep tabs.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+33"/>
+        <location line="+32"/>
         <source>Select or enter the font name. HTML supports a list of fonts, separated with comma.</source>
         <translation>选择或者输入字体名. HTML支持用逗号分隔的字体列表.</translation>
     </message>
     <message>
-        <location line="+43"/>
+        <location line="+49"/>
         <source>&amp;Open files</source>
         <translation>打开(&amp;O)</translation>
     </message>
