@@ -1,8 +1,7 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *   astyle.h
- *
- *   Copyright (C) 2006-2013 by Jim Pattee <jimp03@email.com>
- *   Copyright (C) 1998-2002 by Tal Davidson
+
+ *   Copyright (C) 2014 by Jim Pattee
  *   <http://www.gnu.org/licenses/lgpl-3.0.html>
  *
  *   This file is a part of Artistic Style - an indentation and
@@ -29,10 +28,10 @@
 #define ASTYLE_H
 
 #ifdef __VMS
-#define __USE_STD_IOSTREAM 1
-#include <assert>
+	#define __USE_STD_IOSTREAM 1
+	#include <assert>
 #else
-#include <cassert>
+	#include <cassert>
 #endif
 
 #include <cctype>
@@ -40,47 +39,32 @@
 #include <string>
 #include <vector>
 
-#if defined(__GNUC__)
-#include <string.h>		// need both string and string.h for GCC
+#ifdef __GNUC__
+	#include <string.h>		// need both string and string.h for GCC
 #endif
 
-// define STDCALL and EXPORT for Windows
-// MINGW defines STDCALL in Windows.h (actually windef.h)
-// EXPORT has no value for Visual C if ASTYLE_NO_VCX (no VC Exports) is defined
-#ifdef _WIN32
-#ifndef STDCALL
-#define STDCALL __stdcall
-#endif
-#if defined(_MSC_VER) && defined(ASTYLE_NO_VCX)
-#define EXPORT
-#else
-#define EXPORT __declspec(dllexport)
-#endif
-// define STDCALL and EXPORT for non-Windows
-#else
-#define STDCALL
-#define EXPORT
-#endif	// #ifdef _WIN32
-
 #ifdef _MSC_VER
-#pragma warning(disable: 4996)  // secure version deprecation warnings
-#pragma warning(disable: 4267)  // 64 bit signed/unsigned loss of data
+	#pragma warning(disable: 4996)  // secure version deprecation warnings
+	#pragma warning(disable: 4267)  // 64 bit signed/unsigned loss of data
 #endif
 
 #ifdef __BORLANDC__
-#pragma warn -8004	// variable is assigned a value that is never used
+	#pragma warn -8004	            // variable is assigned a value that is never used
 #endif
 
 #ifdef __INTEL_COMPILER
-#pragma warning(disable:  383)  // value copied to temporary, reference to temporary used
-// #pragma warning(disable:  444)  // destructor for base class is not virtual
-#pragma warning(disable:  981)  // operands are evaluated in unspecified order
+	#pragma warning(disable:  383)  // value copied to temporary, reference to temporary used
+	#pragma warning(disable:  981)  // operands are evaluated in unspecified order
 #endif
 
-using namespace std;
+#ifdef __clang__
+	#pragma clang diagnostic ignored "-Wshorten-64-to-32"
+#endif
 
 namespace astyle {
 
+using namespace std;
+
 enum FileType { C_TYPE = 0, JAVA_TYPE = 1, SHARP_TYPE = 2 };
 
 /* The enums below are not recognized by 'vectors' in Microsoft Visual C++
@@ -94,6 +78,7 @@ enum FormatStyle
 	STYLE_KR,
 	STYLE_STROUSTRUP,
 	STYLE_WHITESMITH,
+	STYLE_VTK,
 	STYLE_BANNER,
 	STYLE_GNU,
 	STYLE_LINUX,
@@ -124,9 +109,11 @@ enum BracketType
 	DEFINITION_TYPE = 16,
 	COMMAND_TYPE = 32,
 	ARRAY_NIS_TYPE = 64,		// also an ARRAY_TYPE
-	ARRAY_TYPE = 128,			// arrays and enums
-	EXTERN_TYPE = 256,			// extern "C", not a command type extern
-	SINGLE_LINE_TYPE = 512
+	ENUM_TYPE = 128,			// also an ARRAY_TYPE
+	INIT_TYPE = 256,			// also an ARRAY_TYPE
+	ARRAY_TYPE = 512,
+	EXTERN_TYPE = 1024,			// extern "C", not a command type extern
+	SINGLE_LINE_TYPE = 2048
 };
 
 enum MinConditional
@@ -168,7 +155,7 @@ enum FileEncoding
 {
 	ENCODING_8BIT,
 	UTF_16BE,
-	UTF_16LE,
+	UTF_16LE,     // Windows default
 	UTF_32BE,
 	UTF_32LE
 };
@@ -184,11 +171,10 @@ enum LineEndFormat
 	LINEEND_CR   = LINEEND_MACOLD
 };
 
-
 //-----------------------------------------------------------------------------
 // Class ASSourceIterator
 // A pure virtual class is used by ASFormatter and ASBeautifier instead of
-// ASStreamIterator. This allows programs using AStyle as a plugin to define
+// ASStreamIterator. This allows programs using AStyle as a plug-in to define
 // their own ASStreamIterator. The ASStreamIterator class must inherit
 // this class.
 //-----------------------------------------------------------------------------
@@ -198,10 +184,12 @@ class ASSourceIterator
 	public:
 		ASSourceIterator() {}
 		virtual ~ASSourceIterator() {}
+		virtual int getStreamLength() const = 0;
 		virtual bool hasMoreLines() const = 0;
 		virtual string nextLine(bool emptyLineWasDeleted = false) = 0;
 		virtual string peekNextLine() = 0;
 		virtual void peekReset() = 0;
+		virtual streamoff tellg() = 0;
 };
 
 //-----------------------------------------------------------------------------
@@ -216,6 +204,7 @@ class ASResource
 		void buildAssignmentOperators(vector<const string*>* assignmentOperators);
 		void buildCastOperators(vector<const string*>* castOperators);
 		void buildHeaders(vector<const string*>* headers, int fileType, bool beautifier = false);
+		void buildIndentableMacros(vector<const pair<const string, const string>* >* indentableMacros);
 		void buildIndentableHeaders(vector<const string*>* indentableHeaders);
 		void buildNonAssignmentOperators(vector<const string*>* nonAssignmentOperators);
 		void buildNonParenHeaders(vector<const string*>* nonParenHeaders, int fileType, bool beautifier = false);
@@ -237,7 +226,8 @@ class ASResource
 		static const string AS_SELECTOR;
 		static const string AS_EXTERN, AS_ENUM;
 		static const string AS_STATIC, AS_CONST, AS_SEALED, AS_OVERRIDE, AS_VOLATILE, AS_NEW;
-		static const string AS_WHERE, AS_SYNCHRONIZED;
+		static const string AS_NOEXCEPT, AS_INTERRUPT, AS_AUTORELEASEPOOL;
+		static const string AS_WHERE, AS_LET, AS_SYNCHRONIZED;
 		static const string AS_OPERATOR, AS_TEMPLATE;
 		static const string AS_OPEN_BRACKET, AS_CLOSE_BRACKET;
 		static const string AS_OPEN_LINE_COMMENT, AS_OPEN_COMMENT, AS_CLOSE_COMMENT;
@@ -257,6 +247,7 @@ class ASResource
 		static const string AS_NOT, AS_BIT_XOR, AS_BIT_OR, AS_BIT_AND, AS_BIT_NOT;
 		static const string AS_QUESTION, AS_COLON, AS_SEMICOLON, AS_COMMA;
 		static const string AS_ASM, AS__ASM__, AS_MS_ASM, AS_MS__ASM;
+		static const string AS_QFOREACH, AS_QFOREVER, AS_FOREVER;
 		static const string AS_FOREACH, AS_LOCK, AS_UNSAFE, AS_FIXED;
 		static const string AS_GET, AS_SET, AS_ADD, AS_REMOVE;
 		static const string AS_DELEGATE, AS_UNCHECKED;
@@ -386,6 +377,8 @@ class ASBeautifier : protected ASResource, protected ASBase
 		bool getEmptyLineFill(void) const;
 		bool getForceTabIndentation(void) const;
 		bool getModeManuallySet(void) const;
+		bool getModifierIndent(void) const;
+		bool getNamespaceIndent(void) const;
 		bool getPreprocDefineIndent(void) const;
 		bool getSwitchIndent(void) const;
 
@@ -395,10 +388,12 @@ class ASBeautifier : protected ASResource, protected ASBase
 		                         const vector<const string*>* possibleHeaders) const;
 		const string* findOperator(const string &line, int i,
 		                           const vector<const string*>* possibleOperators) const;
-		int getNextProgramCharDistance(const string &line, int i) const;
+		int  getNextProgramCharDistance(const string &line, int i) const;
 		int  indexOf(vector<const string*> &container, const string* element) const;
 		void setBlockIndent(bool state);
 		void setBracketIndent(bool state);
+		void setBracketIndentVtk(bool state);
+		string extractPreprocessorStatement(const string &line) const;
 		string trim(const string &str) const;
 		string rtrim(const string &str) const;
 
@@ -415,6 +410,7 @@ class ASBeautifier : protected ASResource, protected ASBase
 		bool isInExternC;
 		bool isInBeautifySQL;
 		bool isInIndentableStruct;
+		bool isInIndentablePreproc;
 
 	private:  // functions
 		ASBeautifier(const ASBeautifier &copy);
@@ -427,6 +423,7 @@ class ASBeautifier : protected ASResource, protected ASBase
 		void processPreprocessor(const string &preproc, const string &line);
 		void registerInStatementIndent(const string &line, int i, int spaceIndentCount,
 		                               int tabIncrementIn, int minIndent, bool updateParenStack);
+		void registerInStatementIndentColon(const string &line, int i, int tabIncrementIn);
 		void initVectors();
 		void initTempStacksContainer(vector<vector<const string*>*>* &container,
 		                             vector<vector<const string*>*>* value);
@@ -443,7 +440,7 @@ class ASBeautifier : protected ASResource, protected ASBase
 		bool isPreprocessorConditionalCplusplus(const string &line) const;
 		bool isInPreprocessorUnterminatedComment(const string &line);
 		bool statementEndsWithComma(const string &line, int index) const;
-		string extractPreprocessorStatement(const string &line) const;
+		string &getIndentedLineReturn(string &newLine, const string &originalLine) const;
 		string preLineWS(int lineIndentCount, int lineSpaceIndentCount) const;
 		template<typename T> void deleteContainer(T &container);
 		template<typename T> void initContainer(T &container, T value);
@@ -499,17 +496,24 @@ class ASBeautifier : protected ASResource, protected ASBase
 		bool isInDefine;
 		bool isInDefineDefinition;
 		bool classIndent;
-		bool isInClassInitializer;
-		bool isInClassHeaderTab;
+		bool isIndentModeOff;
+		bool isInClassHeader;			// is in a class before the opening bracket
+		bool isInClassHeaderTab;		// is in an indentable class header line
+		bool isInClassInitializer;		// is in a class after the ':' initializer
+		bool isInClass;					// is in a class after the opening bracket
 		bool isInObjCMethodDefinition;
 		bool isImmediatelyPostObjCMethodDefinition;
+		bool isInIndentablePreprocBlock;
 		bool isInObjCInterface;
 		bool isInEnum;
+		bool isInEnumTypeID;
+		bool isInLet;
 		bool modifierIndent;
 		bool switchIndent;
 		bool caseIndent;
 		bool namespaceIndent;
 		bool bracketIndent;
+		bool bracketIndentVtk;
 		bool blockIndent;
 		bool labelIndent;
 		bool shouldIndentPreprocDefine;
@@ -526,8 +530,10 @@ class ASBeautifier : protected ASResource, protected ASBase
 		bool previousLineProbationTab;
 		bool lineBeginsWithOpenBracket;
 		bool lineBeginsWithCloseBracket;
+		bool lineBeginsWithComma;
+		bool lineIsCommentOnly;
+		bool lineIsLineCommentOnly;
 		bool shouldIndentBrackettedLine;
-		bool isInClass;
 		bool isInSwitch;
 		bool foundPreCommandHeader;
 		bool foundPreCommandMacro;
@@ -553,6 +559,7 @@ class ASBeautifier : protected ASResource, protected ASBase
 		int  prevFinalLineSpaceIndentCount;
 		int  prevFinalLineIndentCount;
 		int  defineIndentCount;
+		int  preprocBlockIndent;
 		char quoteChar;
 		char prevNonSpaceCh;
 		char currentNonSpaceCh;
@@ -569,8 +576,9 @@ class ASEnhancer : protected ASBase
 	public:  // functions
 		ASEnhancer();
 		virtual ~ASEnhancer();
-		void init(int, int, int, bool, bool, bool, bool, bool);
-		void enhance(string &line, bool isInPreprocessor, bool isInSQL);
+		void init(int, int, int, bool, bool, bool, bool, bool, bool, bool,
+		          vector<const pair<const string, const string>* >*);
+		void enhance(string &line, bool isInNamespace, bool isInPreprocessor, bool isInSQL);
 
 	private:  // functions
 		void    convertForceTabIndentToSpaces(string  &line) const;
@@ -590,8 +598,10 @@ class ASEnhancer : protected ASBase
 		int  tabLength;
 		bool useTabs;
 		bool forceTab;
+		bool namespaceIndent;
 		bool caseIndent;
-		bool preprocessorIndent;
+		bool preprocBlockIndent;
+		bool preprocDefineIndent;
 		bool emptyLineFill;
 
 		// parsing variables
@@ -603,6 +613,7 @@ class ASEnhancer : protected ASBase
 		// unindent variables
 		int  bracketCount;
 		int  switchDepth;
+		int  eventPreprocDepth;
 		bool lookingForCaseBracket;
 		bool unindentNextLine;
 		bool shouldUnindentLine;
@@ -623,6 +634,7 @@ class ASEnhancer : protected ASBase
 		// event table variables
 		bool nextLineIsEventIndent;             // begin event table indent is reached
 		bool isInEventTable;                    // need to indent an event table
+		vector<const pair<const string, const string>* >* indentableMacros;
 
 		// SQL variables
 		bool nextLineIsDeclareIndent;           // begin declare section indent is reached
@@ -674,6 +686,7 @@ class ASFormatter : public ASBeautifier
 		void setParensHeaderPaddingMode(bool mode);
 		void setParensUnPaddingMode(bool state);
 		void setPointerAlignment(PointerAlign alignment);
+		void setPreprocBlockIndent(bool state);
 		void setReferenceAlignment(ReferenceAlign alignment);
 		void setSingleStatementsMode(bool state);
 		void setStripCommentPrefix(bool state);
@@ -690,6 +703,9 @@ class ASFormatter : public ASBeautifier
 		template<typename T> void initContainer(T &container, T value);
 		char peekNextChar() const;
 		BracketType getBracketType();
+		bool adjustChecksumIn(int adjustment);
+		bool computeChecksumIn(const string &currentLine_);
+		bool computeChecksumOut(const string &beautifiedLine);
 		bool addBracketsToStatement();
 		bool removeBracketsFromStatement();
 		bool commentAndHeaderFollows();
@@ -701,6 +717,7 @@ class ASFormatter : public ASBeautifier
 		bool isBeforeAnyLineEndComment(int startPos) const;
 		bool isBeforeMultipleLineEndComments(int startPos) const;
 		bool isBracketType(BracketType a, BracketType b) const;
+		bool isClassInitializer() const;
 		bool isClosingHeader(const string* header) const;
 		bool isCurrentBracketBroken() const;
 		bool isDereferenceOrAddressOf() const;
@@ -715,12 +732,15 @@ class ASFormatter : public ASBeautifier
 		bool isPointerOrReferenceVariable(string &word) const;
 		bool isSharpStyleWithParen(const string* header) const;
 		bool isStructAccessModified(string  &firstLine, size_t index) const;
+		bool isIndentablePreprocessorBlock(string  &firstLine, size_t index);
 		bool isUnaryOperator() const;
+		bool isUniformInitializerBracket() const;
 		bool isImmediatelyPostCast() const;
 		bool isInExponent() const;
 		bool isInSwitchStatement() const;
 		bool isNextCharOpeningBracket(int startChar) const;
 		bool isOkToBreakBlock(BracketType bracketType) const;
+		bool isOperatorPaddingDisabled() const;
 		bool pointerSymbolFollows() const;
 		int  getCurrentLineCommentAdjustment();
 		int  getNextLineCommentAdjustment();
@@ -767,7 +787,7 @@ class ASFormatter : public ASBeautifier
 		void padParens();
 		void processPreprocessor();
 		void resetEndOfStatement();
-		void setAttachClosingBracket(bool state);
+		void setAttachClosingBracketMode(bool state);
 		void setBreakBlocksVariables();
 		void stripCommentPrefix();
 		void testForTimeToSplitFormattedLine();
@@ -789,6 +809,7 @@ class ASFormatter : public ASBeautifier
 		vector<const string*>* operators;
 		vector<const string*>* assignmentOperators;
 		vector<const string*>* castOperators;
+		vector<const pair<const string, const string>* >* indentableMacros;	// for ASEnhancer
 
 		ASSourceIterator* sourceIterator;
 		ASEnhancer* enhancer;
@@ -799,9 +820,10 @@ class ASFormatter : public ASBeautifier
 		vector<bool>* structStack;
 		vector<bool>* questionMarkStack;
 
-		string readyFormattedLine;
 		string currentLine;
 		string formattedLine;
+		string readyFormattedLine;
+		string verbatimDelimiter;
 		const string* currentHeader;
 		const string* previousOperator;    // used ONLY by pad-oper
 		char currentChar;
@@ -809,6 +831,7 @@ class ASFormatter : public ASBeautifier
 		char previousNonWSChar;
 		char previousCommandChar;
 		char quoteChar;
+		streamoff preprocBlockEnd;
 		int  charNum;
 		int  horstmannIndentChars;
 		int  nextLineSpacePadNum;
@@ -816,7 +839,6 @@ class ASFormatter : public ASBeautifier
 		int  spacePadNum;
 		int  tabIncrementIn;
 		int  templateDepth;
-		int  traceLineNumber;
 		int  squareBracketCount;
 		size_t checksumIn;
 		size_t checksumOut;
@@ -845,9 +867,6 @@ class ASFormatter : public ASBeautifier
 		ReferenceAlign referenceAlignment;
 		ObjCColonPad objCColonPadMode;
 		LineEndFormat lineEnd;
-		bool adjustChecksumIn(int adjustment);
-		bool computeChecksumIn(const string &currentLine_);
-		bool computeChecksumOut(const string &beautifiedLine);
 		bool isVirgin;
 		bool shouldPadOperators;
 		bool shouldPadParensOutside;
@@ -858,6 +877,7 @@ class ASFormatter : public ASBeautifier
 		bool shouldUnPadParens;
 		bool shouldConvertTabs;
 		bool shouldIndentCol1Comments;
+		bool shouldIndentPreprocBlock;
 		bool shouldCloseTemplates;
 		bool shouldAttachExternC;
 		bool shouldAttachNamespace;
@@ -872,10 +892,12 @@ class ASFormatter : public ASBeautifier
 		bool isInTemplate;
 		bool doesLineStartComment;
 		bool lineEndsInCommentOnly;
+		bool lineIsCommentOnly;
 		bool lineIsLineCommentOnly;
 		bool lineIsEmpty;
 		bool isImmediatelyPostCommentOnly;
 		bool isImmediatelyPostEmptyLine;
+		bool isInClassInitializer;
 		bool isInQuote;
 		bool isInVerbatimQuote;
 		bool haveLineContinuationChar;
@@ -896,6 +918,7 @@ class ASFormatter : public ASBeautifier
 		bool endOfAsmReached;
 		bool endOfCodeReached;
 		bool lineCommentNoIndent;
+		bool isFormattingModeOff;
 		bool isInEnum;
 		bool isInExecSQL;
 		bool isInAsm;
@@ -923,7 +946,7 @@ class ASFormatter : public ASBeautifier
 		bool shouldRemoveNextClosingBracket;
 		bool isInHorstmannRunIn;
 		bool currentLineBeginsWithBracket;
-		bool shouldAttachClosingBracket;
+		bool attachClosingBracketMode;
 		bool shouldBreakOneLineBlocks;
 		bool shouldReparseCurrentChar;
 		bool shouldBreakOneLineStatements;
@@ -957,12 +980,16 @@ class ASFormatter : public ASBeautifier
 		bool shouldBreakClosingHeaderBlocks;
 		bool isPrependPostBlockEmptyLineRequested;
 		bool isAppendPostBlockEmptyLineRequested;
+		bool isIndentableProprocessor;
+		bool isIndentableProprocessorBlock;
 		bool prependEmptyLine;
 		bool appendOpeningBracket;
 		bool foundClosingHeader;
 		bool isInHeader;
 		bool isImmediatelyPostHeader;
 		bool isInCase;
+		bool isFirstPreprocConditional;
+		bool processedFirstConditional;
 		bool isJavaStaticConstructor;
 
 	private:  // inline functions
@@ -999,16 +1026,4 @@ bool sortOnName(const string* a, const string* b);
 
 // end of astyle namespace  --------------------------------------------------
 
-
-//-----------------------------------------------------------------------------
-// declarations for library build
-// global because they are called externally and are NOT part of the namespace
-//-----------------------------------------------------------------------------
-
-typedef void (STDCALL* fpError)(int, const char*);      // pointer to callback error handler
-typedef char* (STDCALL* fpAlloc)(unsigned long);		// pointer to callback memory allocation
-extern "C" EXPORT char* STDCALL AStyleMain(const char*, const char*, fpError, fpAlloc);
-extern "C" EXPORT const char* STDCALL AStyleGetVersion (void);
-
-
 #endif // closes ASTYLE_H
